#
#	DEVELOPER VERSION
#
#	NOT SUITED/ALLOWED FOR PRODUCTION USE
#	ALL RIGHTS RESERVED
#

#
#	Global system table creation
#

CREATE TABLE config (
	id		int NOT NULL DEFAULT 0 AUTO_INCREMENT,
	cfgkey		char(20) NOT NULL,	# A pair of key
	cfgvalue	char(50) NOT NULL,	# and value

	PRIMARY KEY (id),
	UNIQUE (cfgkey)
);

#
#	MIME type database
#

CREATE TABLE mimetypes (
	id		int NOT NULL DEFAULT 0 AUTO_INCREMENT,
	extension	char(10) NOT NULL,	# File extension
	mimetype	char(20) NOT NULL,	# MIME type, e.g. audio
	subtype		char(20) NOT NULL,	# Subtype, e.g. midi

	PRIMARY KEY (id),
	UNIQUE (extension)
);

#
#	User database
#

CREATE TABLE users (
	id		int NOT NULL DEFAULT 0 AUTO_INCREMENT,
	login		char(20) NOT NULL,	# Login name
	firstname	char(20) NOT NULL,
	lastname	char(25) NOT NULL,
	password	char(20) NOT NULL,
	street		char(50) NOT NULL,
	zip		char(20) NOT NULL,
	town		char(20) NOT NULL,
	country		char(30) NOT NULL,
	phone		char(25) NOT NULL,
	fax		char(25) NOT NULL,
	email		char(60) NOT NULL,
	remarks		char(100) NOT NULL,	# comments by the sysop

	homepage        int NOT NULL,           # user has a homepage
	access_date	int NOT NULL,		# date of last access
	create_date	int NOT NULL,		# date of creation
	rad_online	int NOT NULL,		# seconds online (radius session)
	rad_bytes_in	int NOT NULL,		# TCP/IP bytes sent
	rad_bytes_out	int NOT NULL,		# TCP/IP bytes received

	PRIMARY KEY (id),
	UNIQUE (login),
	UNIQUE (lastname, firstname),
	INDEX (homepage)
);

#	
#	Email database
#

CREATE TABLE email (
	id		int NOT NULL DEFAULT 0 AUTO_INCREMENT,
	reference	int NOT NULL,		# Message ID of reference mail
	from_id		int NOT NULL,		# User ID, -1 if Internet
	to_id		int NOT NULL,		# User ID of recipient
	sender		char(100) NOT NULL,	# Email address if Internet
	id_str		char(100) NOT NULL,	# Message-ID string
	subject		char(100) NOT NULL,	# Message subject
	datestamp	int NOT NULL,		# Message date
	read		int NOT NULL,		# Flag if email has been read
	body		int NOT NULL,		# Large object ID of the body
	head		int NOT NULL,		# OID of header if Internet

	PRIMARY KEY (id),
	INDEX (datestamp),
	INDEX (to_id, read),
	INDEX (reference)
);

#
#	Mail queue for Internet messages to be sent by SMTP
#

CREATE TABLE mailqueue (
	id		int NOT NULL DEFAULT 0 AUTO_INCREMENT,
	received	int NOT NULL,		# date of creation
	processed	int NOT NULL,		# date of last attempt to send
	pid		int NOT NULL,		# process ID of current handler
	file_id		int NOT NULL,		# object ID of spool file

	PRIMARY KEY (id, file_id),
	INDEX (pid, processed)
);

#
#	News (boards) messages
#

CREATE TABLE newsgroups (
	id		int NOT NULL DEFAULT 0 AUTO_INCREMENT,
	name		char(60) NOT NULL,	# Name of the group
	read_group	int NOT NULL,		# Read access group
	write_group	int NOT NULL,		# Write access user group
	delete_group    int NOT NULL,           # Delete access user group
	ttl		int NOT NULL,		# How many days to keep news
	datestamp	int NOT NULL,		# Date of creation

	PRIMARY KEY (id),
	UNIQUE (name)
);

CREATE TABLE news (
	id		int NOT NULL DEFAULT 0 AUTO_INCREMENT,
	reference	int NOT NULL,		# Message ID of reference news
	group_id	int NOT NULL,		# Newsgroup ID
	from_id		int NOT NULL,		# User ID
	id_str		char(100) NOT NULL,	# Message ID string
	subject		char(100) NOT NULL,	# Message subject
	datestamp	int NOT NULL,		# Message date
	body		int NOT NULL,		# Large object ID of the body
	head		int NOT NULL,		# OID of header if Internet

	PRIMARY KEY (id),
	INDEX (group_id, datestamp),
	INDEX (reference),
	INDEX (id_str)
);

CREATE TABLE readnews (				# Stores last-read counters
	id		int NOT NULL DEFAULT 0 AUTO_INCREMENT,
	user_id		int NOT NULL,
	group_id	int NOT NULL,
	msg_id		int NOT NULL,

	PRIMARY KEY (id),
	INDEX (group_id, user_id)
);

#
#	Access permissions on HTML directories
#

CREATE TABLE access_dir (
	id		int NOT NULL DEFAULT 0 AUTO_INCREMENT,
	read_group	int       NOT NULL,	# group to download files
	create_group	int       NOT NULL,	# group to create new files
	delete_group	int       NOT NULL,	# to delete existing files
	exec_group	int       NOT NULL,     # to execute cgi scripts
	dir		char(120) NOT NULL,	# access this directory

	PRIMARY KEY (id),
	UNIQUE (dir)
);

#
#	Access permissions for built-in functions
#

CREATE TABLE access_action (
	id		int NOT NULL DEFAULT 0 AUTO_INCREMENT,
	group_id	int       NOT NULL,	# Required user group to
	action		char(50)  NOT NULL,	# perform this action
	url_ok		char(100) NOT NULL,
	url_fail	char(100) NOT NULL,

	PRIMARY KEY (id),
	UNIQUE (action)
);

#
#	Chat rooms and bulletin boards
#

CREATE TABLE chatboards (
	id		int NOT NULL DEFAULT 0 AUTO_INCREMENT,
	name		char(60) NOT NULL,	# Name of the group
	read_group	int NOT NULL,		# Read access user group
	write_group	int NOT NULL,		# Write access user group
	ttl		int NOT NULL,		# How many days to keep msgs

	PRIMARY KEY (id),
	UNIQUE (name)
);

#
#	Chat messages
#

CREATE TABLE chat (
	id		int NOT NULL DEFAULT 0 AUTO_INCREMENT,
	group_id	int NOT NULL,		# Chat room ID
	user_id		int NOT NULL,		# User ID
	message		blob NOT NULL,		# Message text
	color           char(10) NOT NULL,	# Color in hhhhhh notation
	datestamp	int NOT NULL,		# date

	PRIMARY KEY (id),
	INDEX (group_id, datestamp)
);

#
#	File database
#

CREATE TABLE files (
	id		int NOT NULL DEFAULT 0 AUTO_INCREMENT,
	user_id		int NOT NULL,			# Uploaders user ID
	visible		tinyint NOT NULL DEFAULT 1,	# Checked by sysop?
	file		char(80)  NOT NULL,	# File name
	section		char(80)  NOT NULL,	# File area
	title		char(80)  NOT NULL,     # Short description
	descr		blob NOT NULL,		# Full description
	datestamp	int NOT NULL,

	PRIMARY KEY (id),
	INDEX (section(20)),
	INDEX (title(20)),
	INDEX (datestamp)
);

#
#	User group definitions
#

CREATE TABLE groups (
	id		int NOT NULL DEFAULT 0 AUTO_INCREMENT,
	name		char(60) NOT NULL,	# Group name

	PRIMARY KEY (id),
	UNIQUE (name)
);

#
#	Group memberships
#

CREATE TABLE group_members (
	id		int NOT NULL DEFAULT 0 AUTO_INCREMENT,
	user_id		int NOT NULL,
	group_id	int NOT NULL,

	PRIMARY KEY (id),
	UNIQUE (group_id, user_id),
	INDEX (user_id)
);

#
#	Mail aliases
#

CREATE TABLE mail_alias (
	id		int NOT NULL DEFAULT 0 AUTO_INCREMENT,
	orig_addr	char(100) NOT NULL,
	dest_addr	char(100) NOT NULL,

	PRIMARY KEY (id),
	UNIQUE (orig_addr)
);
